/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
  Copyright (c) 2012-2021, Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;

const Main = imports.ui.main;
const StatusAccessibility = imports.ui.status.accessibility;

const ExtensionUtils = imports.misc.extensionUtils;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const ACCESSIBILITY_DEFAULT = 0;
const ACCESSIBILITY_VISIBLE = 1;

const KEY_SHOW_ACCESSIBILITY = 'show-accessibility';

let _a11y = Main.panel.statusArea.a11y;

const ATIndicator = new Lang.Class({
    Name: 'ATIndicator',

    _init: function() {
        this._changedAccessibility(true);
        this._settingsChangedId = Convenience.Settings.connect('changed::'+KEY_SHOW_ACCESSIBILITY, Lang.bind(this, this._updateAccessibility));
    },

    _changedAccessibility: function(enabled) {
        /**
         *  Typing error in accessibility.js in function _queueSyncMenuVisibility:
         *  - this._syncMenuVisbilityIdle instead of this._syncMenuVisibilityIdle
         */
        let typingError = Convenience.checkVersion([ '3.18', '3.20', '3.22' ]);
        if (enabled) {
            _a11y._syncMenuVisibility = function() {
                let result = StatusAccessibility.ATIndicator.prototype._syncMenuVisibility.call(this);
                let showAccessibility = Convenience.Settings.get_enum(KEY_SHOW_ACCESSIBILITY);
                if (showAccessibility !== ACCESSIBILITY_DEFAULT) this.actor.visible = showAccessibility === ACCESSIBILITY_VISIBLE;
                return result;
            };
            if (typingError) _a11y._queueSyncMenuVisibility = function() {
                if (this._syncMenuVisibilityIdle) return;
                this._syncMenuVisibilityIdle = Mainloop.idle_add(Lang.bind(this, this._syncMenuVisibility));
                GLib.Source.set_name_by_id(this._syncMenuVisibilityIdle, '[gnome-shell] this._syncMenuVisibility');
            };
        } else {
            if (typingError) _a11y._queueSyncMenuVisibility = StatusAccessibility.ATIndicator.prototype._queueSyncMenuVisibility;
            _a11y._syncMenuVisibility = StatusAccessibility.ATIndicator.prototype._syncMenuVisibility;
        }
        this._updateAccessibility();
    },

    _updateAccessibility: function() {
        _a11y._syncMenuVisibility.call(_a11y);
    },

    destroy: function() {
        Convenience.Settings.disconnect(this._settingsChangedId);
        this._changedAccessibility(false);
    }
});

function get() {
    return new ATIndicator();
}
