/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
  Copyright (c) 2012-2021, Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;

const Clutter = imports.gi.Clutter;
const St = imports.gi.St;

const Main = imports.ui.main;

const ExtensionUtils = imports.misc.extensionUtils;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const ACTIVITIES_DEFAULT = 0;
const ACTIVITIES_ICON = 1;
const ACTIVITIES_NONE = 2;

const KEY_SHOW_ACTIVITIES = 'show-activities';

let _activities = Main.panel.statusArea.activities;

const ActivitiesButton = new Lang.Class({
    Name: 'ActivitiesButton',

    _init: function() {
        this._hbox = new St.BoxLayout({ style_class: 'panel-status-menu-box' });
        this._icon = new St.Icon({ icon_name: 'start-here-symbolic', style_class: 'system-status-icon' });
        this._hbox.add_child(this._icon);
        _activities.actor.remove_actor(_activities._label);
        this._hbox.add_child(_activities._label);
        _activities.actor.add_child(this._hbox);
        this._settingsChangedId = Convenience.Settings.connect('changed::'+KEY_SHOW_ACTIVITIES, Lang.bind(this, this._onChangedShowActivities));
        this._onChangedShowActivities();
    },

    _onChangedShowActivities: function() {
        let showActivities = Convenience.Settings.get_enum(KEY_SHOW_ACTIVITIES);
        _activities._label.visible = showActivities === ACTIVITIES_DEFAULT;
        this._icon.visible = showActivities === ACTIVITIES_ICON;
        this._setStyleParent(showActivities !== ACTIVITIES_NONE);
    },

    _setStyleParent: function(visible) {
        if (_activities.container.visible !== visible) {
            _activities.container.visible = visible;
            let rtl = Main.panel.actor.get_text_direction() === Clutter.TextDirection.RTL;
            Main.panel._leftCorner.setStyleParent.call(Main.panel._leftCorner, Main.panel[rtl ? '_rightBox' : '_leftBox']);
        }
    },

    destroy: function() {
        Convenience.Settings.disconnect(this._settingsChangedId);
        _activities.actor.remove_actor(this._hbox);
        this._hbox.remove_actor(_activities._label);
        _activities.actor.add_actor(_activities._label);
        _activities._label.show();
        this._setStyleParent(true);
        this._hbox.destroy_all_children();
        this._hbox.destroy();
    }
});

function get() {
    return new ActivitiesButton();
}
