/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
  Copyright (c) 2012-2021, Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;

const St = imports.gi.St;

const Main = imports.ui.main;

const ExtensionUtils = imports.misc.extensionUtils;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

let [ _dateMenuBox, _dateMenuEvents ] = (function() {
    let dateMenu = Main.panel.statusArea.dateMenu;
    return [ dateMenu.actor.get_children()[0], dateMenu._messageList._eventsSection._list, ];
})();

const DateMenuButton = new Lang.Class({
    Name: 'DateMenuButton',

    _init: function() {
        this._iconEvents = new St.Icon({ icon_name: 'x-office-calendar-symbolic', style_class: 'system-status-icon' });
        _dateMenuBox.insert_child_at_index(this._iconEvents, 1);
        this._dateMenuEventsChangedId = [
            _dateMenuEvents.connect('actor-added', Lang.bind(this, this._onChangedEvents)),
            _dateMenuEvents.connect('actor-removed', Lang.bind(this, this._onChangedEvents))
        ];
        this._onChangedEvents();
    },

    _onChangedEvents: function() {
        this._iconEvents.visible = _dateMenuEvents.get_children().length > 0;
    },

    destroy: function() {
        this._dateMenuEventsChangedId.forEach(function(id) {
            _dateMenuEvents.disconnect(id);
        });
        _dateMenuBox.remove_actor(this._iconEvents);
        this._iconEvents.destroy();
    }
});

function get() {
    return new DateMenuButton();
}
