/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
  Copyright (c) 2012-2021, Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;

const ExtensionSystem = imports.ui.extensionSystem;
const Main = imports.ui.main;

const ExtensionUtils = imports.misc.extensionUtils;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const KEY_SHOW_DROPDOWN_ARROW = 'show-dropdown-arrow';

const DropDownArrow = new Lang.Class({
    Name: 'DropDownArrow',

    _init: function() {
        this._settingsChangedId = Convenience.Settings.connect('changed::'+KEY_SHOW_DROPDOWN_ARROW, Lang.bind(this, this._onChangedShowDropDownArrow));
        this._extensionStateChangedID = ExtensionSystem.connect('extension-state-changed', Lang.bind(this, this._onChangedShowDropDownArrow));
        this._onChangedShowDropDownArrow();
    },

    _onChangedShowDropDownArrow: function() {
        this._updateVisibility(Convenience.Settings.get_boolean(KEY_SHOW_DROPDOWN_ARROW), null);
    },

    _updateVisibility: function(visible, child) {
        if (!child) child = Main.panel.actor;
        if (child.has_style_class_name && child.has_style_class_name('popup-menu-arrow')) {
            child.visible = visible;
        } else if (child.get_n_children() > 0) {
            let children = child.get_children();
            children.forEach(function(child) {
                this._updateVisibility(visible, child);
            }, this);
        }
    },

    destroy: function() {
        ExtensionSystem.disconnect(this._extensionStateChangedID);
        Convenience.Settings.disconnect(this._settingsChangedId);
        this._updateVisibility(true, null);
    }
});

function get() {
    return new DropDownArrow();
}
