/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
  Copyright (c) 2012-2021, Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;

const ExtensionUtils = imports.misc.extensionUtils;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const PANELMANAGER_CHILDRENS = [
    'showDesktop',
    'favorites',
    'places',
    'applications',
    'recycleBin',
    'activities',
    'dateMenu',
    'accessibility',
    'keyboard',
    'systemMenu',
    'systemMenuSystem',
    'systemMenuVolume',
    'hotCorners',
    'dropDownArrow',
    'dash'
];

const PanelManager = new Lang.Class({
    Name: 'PanelManager',

    _init: function() {
        this._children = [];
        PANELMANAGER_CHILDRENS.forEach(function(child) {
            try { this._children.push(Me.imports[child].get()); } catch (e) {}
        }, this);
    },

    destroy: function() {
        while (this._children.length > 0) {
            let child = this._children.pop();
            child.destroy();
        }
    }
});

function init(metadata) {
    Convenience.initTranslations();
}

let _extension = null;

function enable() {
    if (_extension === null) _extension = new PanelManager();
}

function disable() {
    if (_extension !== null) {
        _extension.destroy();
        _extension = null;
    }
}
