/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
  Copyright (c) 2012-2021, Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;

const Main = imports.ui.main;
const StatusKeyboard = imports.ui.status.keyboard;

const ExtensionUtils = imports.misc.extensionUtils;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const KEYBOARD_DEFAULT = 0;
const KEYBOARD_VISIBLE = 1;

const KEY_SHOW_KEYBOARD = 'show-keyboard';

let _keyboard = Main.panel.statusArea.keyboard;

const InputSourceIndicator = new Lang.Class({
    Name: 'InputSourceIndicator',

    _init: function() {
        this._changedKeyboard(true);
        this._settingsChangedId = Convenience.Settings.connect('changed::'+KEY_SHOW_KEYBOARD, Lang.bind(this, this._updateKeyboard));
    },

    _changedKeyboard: function(enabled) {
        if (enabled) {
            _keyboard._currentSourceChanged = function(manager, oldSource) {
                StatusKeyboard.InputSourceIndicator.prototype._currentSourceChanged.call(this, manager, oldSource);
                let showKeyboard = Convenience.Settings.get_enum(KEY_SHOW_KEYBOARD);
                if (showKeyboard !== KEYBOARD_DEFAULT) {
                    let numInputSources = Object.keys(this._inputSourceManager.inputSources).length;
                    if (numInputSources > 0) {
                        this._menuItems[0].setSensitive(true);
                        if (numInputSources === 1) {
                            this._indicatorLabels[0].show();
                            this._menuItems[0].setSensitive(false);
                        }
                        this.actor.visible = showKeyboard === KEYBOARD_VISIBLE;
                    }
                }
            }
        } else {
            _keyboard._currentSourceChanged = StatusKeyboard.InputSourceIndicator.prototype._currentSourceChanged;
        }
        this._updateKeyboard();
    },

    _updateKeyboard: function() {
        _keyboard._currentSourceChanged.call(_keyboard);
    },

    destroy: function() {
        Convenience.Settings.disconnect(this._settingsChangedId);
        this._changedKeyboard(false);
    }
});

function get() {
    return new InputSourceIndicator();
}
