/* -*- mode: js2; js2-basic-offset: 4; indent-tabs-mode: nil -*- */
/*
  Copyright (c) 2012-2021, Dieter Schärf <ds@dschaerf.de>

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>.
*/

const Lang = imports.lang;

const Shell = imports.gi.Shell;
const St = imports.gi.St;

const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;

const ExtensionUtils = imports.misc.extensionUtils;

const Me = ExtensionUtils.getCurrentExtension();

const Convenience = Me.imports.convenience;

const _ = Convenience.getTranslations();

const ShowDesktopButton = new Lang.Class({
    Name: 'ShowDesktopButton',
    Extends: PanelMenu.Button,

    _init: function() {
        this.parent(0.0, _("Show Desktop"), true);
        this._windows = [];
        this._icon = new St.Icon({ icon_name: 'video-display-symbolic', style_class: 'system-status-icon' });
        this.actor.add_child(this._icon);
        this.actor.connect('button-press-event', Lang.bind(this, this._onButtonPressEvent));
    },

    _onButtonPressEvent: function() {
        let tracker = Shell.WindowTracker.get_default();
        let workspace = global.workspace_manager.get_active_workspace();
        let workspaceIndex = workspace.index();
        let workspaceWindows = workspace.list_windows();
        if (this._windows[workspaceIndex]) {
            workspaceWindows.forEach(function(window) {
                if (tracker.get_window_app(window)) {
                    let restore = true;
                    for (let i = 0; i < this._windows[workspaceIndex].length; i++) {
                        if (window === this._windows[workspaceIndex][i]) {
                            restore = false;
                            break;
                        }
                    }
                    if (restore) window.unminimize();
                }
            }, this);
            this._windows[workspaceIndex] = null;
        } else {
            this._windows[workspaceIndex] = [];
            workspaceWindows.forEach(function(window) {
                if (tracker.get_window_app(window)) {
                    let canClose = window.can_close ? window.can_close() : true;
                    if (canClose && !window.minimized) {
                        window.minimize();
                    } else {
                        this._windows[workspaceIndex].push(window);
                    }
                }
            }, this);
        }
        Main.overview.hide();
    }
});

function get() {
    return Main.panel.addToStatusArea('dschaerfShowDesktop', new ShowDesktopButton(), 1, 'left');
}
